@@ -1,8 +1,6 @@
 import os
 import subprocess
 import shutil
-from py_everything_exceptions import pycacheNotFoundError, installModulesFailedError
-
 
 def hello_world():
     string = 'Hello, World!'
@@ -16,8 +14,9 @@ def print_no_newline(*args):
 
 def clearPycache(path):
     if not shutil.rmtree(os.path.join(path, "__pycache__")):
-        raise pycacheNotFoundError(
-            "The '__pycache__' folder was not found in the given directory. Check if it exists and try again!")
+        return False
+    else:
+        return True
 
 
 def install_modules(*args):
@@ -26,4 +25,4 @@ def install_modules(*args):
         if subprocess.run(command):
             return True
         else:
-            raise installModulesFailedError
+            return False
